<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nl" sourcelanguage="en">
<context>
    <name>AgendaPlug</name>
    <message>
        <location filename="../AgendaPlug.cpp" line="28"/>
        <source>Jump to today</source>
        <translation>Ga naar vandaag</translation>
    </message>
    <message>
        <location filename="../AgendaPlug.cpp" line="29"/>
        <source>Jump to</source>
        <translation>Ga naar</translation>
    </message>
    <message>
        <location filename="../AgendaPlug.cpp" line="30"/>
        <source>New event</source>
        <translation>Nieuwe gebeurtenis</translation>
    </message>
    <message>
        <location filename="../AgendaPlug.h" line="20"/>
        <source>Agenda</source>
        <translation>Agenda</translation>
    </message>
</context>
<context>
    <name>AlarmPickDialog</name>
    <message>
        <location filename="../AlarmPickDialog.ui" line="6"/>
        <source>Alarm</source>
        <translation>Alarm</translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.ui" line="38"/>
        <source>In advance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.ui" line="48"/>
        <source>Arbitrary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.ui" line="66"/>
        <source>Hours</source>
        <translation>Uren</translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.ui" line="86"/>
        <source>Minutes</source>
        <translation>Minuten</translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.ui" line="106"/>
        <source>Seconds</source>
        <translation>Seconden</translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.ui" line="20"/>
        <source>Enable</source>
        <translation>Aanzetten</translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.cpp" line="15"/>
        <source>Done</source>
        <translation>Gereed</translation>
    </message>
</context>
<context>
    <name>AlarmPickSelector</name>
    <message>
        <location filename="../AlarmPickSelector.cpp" line="142"/>
        <source>None</source>
        <translation>Geen</translation>
    </message>
    <message>
        <location filename="../AlarmPickSelector.cpp" line="154"/>
        <source>Exact</source>
        <translation>Exact</translation>
    </message>
    <message numerus="yes">
        <location filename="../AlarmPickSelector.cpp" line="156"/>
        <source>%n hour(s) before</source>
        <translation>
            <numerusform>%n uur voor</numerusform>
            <numerusform>%n uur voor</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../AlarmPickSelector.cpp" line="157"/>
        <source>%n minute(s) before</source>
        <translation>
            <numerusform>%n minuut voor</numerusform>
            <numerusform>%n minuten voor</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../AlarmPickSelector.cpp" line="158"/>
        <source>%n second(s) before</source>
        <translation>
            <numerusform>%n seconde voor</numerusform>
            <numerusform>%n seconden voor</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../AlarmPickSelector.cpp" line="160"/>
        <source>%1:%2:%3 before</source>
        <translation>%1:%2:%3 voor</translation>
    </message>
</context>
<context>
    <name>BirthdayEditDialog</name>
    <message>
        <location filename="../BirthdayEditDialog.ui" line="6"/>
        <source>Edit event</source>
        <translation>Gebeurtenis bewerken</translation>
    </message>
    <message>
        <location filename="../BirthdayEditDialog.ui" line="12"/>
        <source>Alarm</source>
        <translation>Alarm</translation>
    </message>
</context>
<context>
    <name>ByDayWidget</name>
    <message>
        <location filename="../recurrence/ByDayWidget.cpp" line="37"/>
        <source>From beginning</source>
        <translation>Van begin</translation>
    </message>
    <message>
        <location filename="../recurrence/ByDayWidget.cpp" line="38"/>
        <source>From end</source>
        <translation>Van eind</translation>
    </message>
    <message>
        <location filename="../recurrence/ByDayWidget.cpp" line="49"/>
        <source>By day of month</source>
        <translation>Per dag van de maand</translation>
    </message>
    <message>
        <location filename="../recurrence/ByDayWidget.cpp" line="51"/>
        <source>By week of year</source>
        <translation>Per week van het jaar</translation>
    </message>
    <message>
        <location filename="../recurrence/ByDayWidget.cpp" line="53"/>
        <source>By day of year</source>
        <translation>Per dag van het jaar</translation>
    </message>
</context>
<context>
    <name>ByMonthWidget</name>
    <message>
        <location filename="../recurrence/ByMonthWidget.cpp" line="20"/>
        <source>By month</source>
        <translation>Per maand</translation>
    </message>
</context>
<context>
    <name>ByWeekdayWidget</name>
    <message>
        <location filename="../recurrence/ByWeekdayWidget.cpp" line="21"/>
        <source>By day of week</source>
        <translation>Per dag van de week</translation>
    </message>
    <message>
        <location filename="../recurrence/ByWeekdayWidget.cpp" line="55"/>
        <source>From beginning</source>
        <translation>Van start</translation>
    </message>
    <message>
        <location filename="../recurrence/ByWeekdayWidget.cpp" line="56"/>
        <source>From end</source>
        <translation>Van eind</translation>
    </message>
</context>
<context>
    <name>CalendarEditDialog</name>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="52"/>
        <source>Edit calendar</source>
        <translation>Bewerkt kalender</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.ui" line="27"/>
        <source>Local</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.ui" line="37"/>
        <source>Birthday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.ui" line="53"/>
        <source>Color</source>
        <translation>Kleur</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.ui" line="63"/>
        <source>Visible</source>
        <translation>Zichtbaar</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="42"/>
        <source>Export</source>
        <translation>Exporteren</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="43"/>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="90"/>
        <source>New calendar</source>
        <translation>Nieuwe kalender</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="94"/>
        <source>Save</source>
        <translation>Opslaan</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="141"/>
        <location filename="../settings/CalendarEditDialog.cpp" line="166"/>
        <source>Error occurred</source>
        <translation>Fout opgetreden</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="175"/>
        <source>Save file</source>
        <translation>Bewaar bestand</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="193"/>
        <source>This calendar cannot be deleted. Delete all calendar content instead?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="201"/>
        <source>Delete this calendar and its events, tasks and notes?</source>
        <translation>Deze kalender met gebeurtenissen, taken en notities verwijderen?</translation>
    </message>
</context>
<context>
    <name>CalendarPickDialog</name>
    <message>
        <location filename="../CalendarPickDialog.ui" line="6"/>
        <source>Calendar</source>
        <translation>Kalender</translation>
    </message>
</context>
<context>
    <name>CalendarsConfigDialog</name>
    <message>
        <location filename="../settings/CalendarsConfigDialog.ui" line="6"/>
        <source>Edit calendars</source>
        <translation>Kalenders bewerken</translation>
    </message>
    <message>
        <location filename="../settings/CalendarsConfigDialog.cpp" line="27"/>
        <source>New</source>
        <translation>Nieuw</translation>
    </message>
</context>
<context>
    <name>CalendarsConfigSelector</name>
    <message numerus="yes">
        <location filename="../settings/CalendarsConfigSelector.cpp" line="16"/>
        <source>%n visible</source>
        <translation>
            <numerusform>%n zichtbaar</numerusform>
            <numerusform>%n zichtbaar</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ColorPickDialog</name>
    <message>
        <location filename="../ColorPickDialog.ui" line="6"/>
        <source>Color</source>
        <translation>Kleur</translation>
    </message>
    <message>
        <location filename="../ColorPickDialog.cpp" line="12"/>
        <source>Done</source>
        <translation>Gereed</translation>
    </message>
</context>
<context>
    <name>ComponentEditDialog</name>
    <message>
        <location filename="../ComponentEditDialog.h" line="22"/>
        <source>Save</source>
        <translation>Opslaan</translation>
    </message>
    <message>
        <location filename="../ComponentEditDialog.h" line="29"/>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
</context>
<context>
    <name>ComponentListDelegate</name>
    <message>
        <location filename="../ComponentListDelegate.h" line="80"/>
        <source>All
day</source>
        <translation>Hele dag</translation>
    </message>
</context>
<context>
    <name>ComponentListWidget</name>
    <message>
        <location filename="../ComponentListWidget.cpp" line="72"/>
        <source>Edit</source>
        <translation>Bewerken</translation>
    </message>
    <message>
        <location filename="../ComponentListWidget.cpp" line="73"/>
        <source>Clone</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ComponentListWidget.cpp" line="74"/>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
</context>
<context>
    <name>ComponentWidget</name>
    <message>
        <location filename="../week/ComponentWidget.cpp" line="181"/>
        <source>Edit</source>
        <translation>Bewerken</translation>
    </message>
    <message>
        <location filename="../week/ComponentWidget.cpp" line="182"/>
        <source>Clone</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../week/ComponentWidget.cpp" line="183"/>
        <source>Delete</source>
        <translation>Verwijder</translation>
    </message>
</context>
<context>
    <name>DateFormatDialog</name>
    <message>
        <location filename="../settings/DateFormatDialog.ui" line="6"/>
        <source>Date formats</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/DateFormatDialog.ui" line="20"/>
        <source>Full</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/DateFormatDialog.ui" line="37"/>
        <source>Partial</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/DateFormatDialog.ui" line="72"/>
        <source>Day</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/DateFormatDialog.ui" line="89"/>
        <source>Month</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/DateFormatDialog.ui" line="106"/>
        <source>Year</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/DateFormatDialog.cpp" line="24"/>
        <source>Save</source>
        <translation>Opslaan</translation>
    </message>
</context>
<context>
    <name>DatePickDialog</name>
    <message>
        <location filename="../DatePickDialog.cpp" line="27"/>
        <source>Done</source>
        <translation>Gereed</translation>
    </message>
    <message>
        <location filename="../DatePickDialog.cpp" line="181"/>
        <source>Week %1 (%2 - %3)</source>
        <translation>Week %1 (%2 - %3)</translation>
    </message>
    <message>
        <location filename="../DatePickDialog.ui" line="6"/>
        <source>Select date</source>
        <translation>Selecteer datum</translation>
    </message>
</context>
<context>
    <name>DayNumberDialog</name>
    <message>
        <location filename="../recurrence/DayNumberDialog.h" line="17"/>
        <source>Enter day number</source>
        <translation>Geef dag nummer</translation>
    </message>
    <message>
        <location filename="../recurrence/DayNumberDialog.h" line="24"/>
        <source>Add</source>
        <translation>Toevoegen</translation>
    </message>
</context>
<context>
    <name>DayWindow</name>
    <message>
        <location filename="../DayWindow.ui" line="35"/>
        <source>Previous day</source>
        <translation>Vorige dag</translation>
    </message>
    <message>
        <location filename="../DayWindow.ui" line="40"/>
        <source>Next day</source>
        <translation>Volgende dag</translation>
    </message>
    <message>
        <location filename="../DayWindow.ui" line="45"/>
        <source>Jump to today</source>
        <translation>Ga naar vandaag</translation>
    </message>
    <message>
        <location filename="../DayWindow.ui" line="50"/>
        <source>Jump to</source>
        <translation>Ga naar</translation>
    </message>
</context>
<context>
    <name>DetailedCalendarDelegate</name>
    <message numerus="yes">
        <location filename="../settings/DetailedCalendarDelegate.h" line="30"/>
        <source>%n event(s)</source>
        <translation>
            <numerusform>%n gebeurtenis</numerusform>
            <numerusform>%n gebeurtenissen</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../settings/DetailedCalendarDelegate.h" line="31"/>
        <source>%n task(s)</source>
        <translation>
            <numerusform>%n taak</numerusform>
            <numerusform>%n taken</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../settings/DetailedCalendarDelegate.h" line="32"/>
        <source>%n note(s)</source>
        <translation>
            <numerusform>%n notitie</numerusform>
            <numerusform>%n notities</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>EventEditDialog</name>
    <message>
        <location filename="../EventEditDialog.ui" line="27"/>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="40"/>
        <source>Where</source>
        <translation>Waar</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="55"/>
        <source>All day</source>
        <translation>Hele dag</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="64"/>
        <source>From</source>
        <translation>Van</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="90"/>
        <source>To</source>
        <translation>Tot</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="118"/>
        <source>Repeat</source>
        <translation>Herhaal</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="128"/>
        <source>Calendar</source>
        <translation>Kalender</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="135"/>
        <source>Alarm</source>
        <translation>Alarm</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="142"/>
        <source>Description</source>
        <translation>Beschrijving</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.cpp" line="28"/>
        <source>Edit event</source>
        <translation>Gebeurtenis bewerken</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.cpp" line="31"/>
        <source>New event</source>
        <translation>Nieuwe gebeurtenis</translation>
    </message>
</context>
<context>
    <name>EventWindow</name>
    <message>
        <location filename="../EventWindow.ui" line="6"/>
        <source>Event</source>
        <translation>Gebeurtenis</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="62"/>
        <source>To</source>
        <translation>T/m</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="86"/>
        <source>Repeat</source>
        <translation>Herhaal</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="110"/>
        <source>Alarm</source>
        <translation>Alarm</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="179"/>
        <source>Previous event</source>
        <translation>Vorige gebeurtenis</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="184"/>
        <source>Next event</source>
        <translation>Volgende gebeurtenis</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="189"/>
        <source>Edit event</source>
        <translation>Gebeurtenis bewerken</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="194"/>
        <source>Delete event</source>
        <translation>Gebeurtenis verwijderen</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="199"/>
        <source>Clone event</source>
        <translation>Gebeurtenis kopiëren</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="204"/>
        <source>Automatic links</source>
        <translation>Automatische verwijzingen</translation>
    </message>
    <message>
        <location filename="../EventWindow.cpp" line="146"/>
        <source>From</source>
        <translation>Van</translation>
    </message>
    <message>
        <location filename="../EventWindow.cpp" line="146"/>
        <source>On</source>
        <translation>Op</translation>
    </message>
    <message>
        <location filename="../EventWindow.cpp" line="216"/>
        <location filename="../EventWindow.cpp" line="237"/>
        <source>No more events</source>
        <translation>Geen gebeurtenissen meer</translation>
    </message>
    <message>
        <location filename="../EventWindow.cpp" line="269"/>
        <source>Edit</source>
        <translation>Bewerken</translation>
    </message>
    <message>
        <location filename="../EventWindow.cpp" line="270"/>
        <source>Clone</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../EventWindow.cpp" line="271"/>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImportDialog</name>
    <message>
        <location filename="../ImportDialog.ui" line="6"/>
        <source>Select calendar</source>
        <translation>Selecteer kalender</translation>
    </message>
    <message>
        <location filename="../ImportDialog.cpp" line="44"/>
        <source>Import</source>
        <translation>Importeer</translation>
    </message>
    <message>
        <location filename="../ImportDialog.cpp" line="50"/>
        <source>New calendar</source>
        <translation>Nieuwe kalender</translation>
    </message>
    <message>
        <location filename="../ImportDialog.cpp" line="77"/>
        <source>Importing aborted</source>
        <translation>Import afgebroken</translation>
    </message>
    <message numerus="yes">
        <location filename="../ImportDialog.cpp" line="112"/>
        <source>%n event(s)</source>
        <translation>
            <numerusform>%n gebeurtenis</numerusform>
            <numerusform>%n gebeurtenissen</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../ImportDialog.cpp" line="113"/>
        <source>%n task(s)</source>
        <translation>
            <numerusform>%n taak</numerusform>
            <numerusform>%n taken</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../ImportDialog.cpp" line="114"/>
        <source>%n note(s)</source>
        <translation>
            <numerusform>%n notitie</numerusform>
            <numerusform>%n notities</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../ImportDialog.cpp" line="126"/>
        <location filename="../ImportDialog.cpp" line="194"/>
        <source>Error occurred</source>
        <translation>Fout opgetreden</translation>
    </message>
    <message>
        <location filename="../ImportDialog.cpp" line="187"/>
        <source>Some items already in calendar</source>
        <translation>Sommige items zijn al in de kalender</translation>
    </message>
</context>
<context>
    <name>JournalEditDialog</name>
    <message>
        <location filename="../JournalEditDialog.ui" line="22"/>
        <source>Calendar</source>
        <translation>Kalender</translation>
    </message>
    <message>
        <location filename="../JournalEditDialog.cpp" line="21"/>
        <source>Edit note</source>
        <translation>Bewerk notitie</translation>
    </message>
    <message>
        <location filename="../JournalEditDialog.cpp" line="24"/>
        <source>New note</source>
        <translation>Nieuwe notitie</translation>
    </message>
</context>
<context>
    <name>JournalsPlug</name>
    <message>
        <location filename="../JournalsPlug.cpp" line="28"/>
        <source>New note</source>
        <translation>Nieuwe notitie</translation>
    </message>
    <message>
        <location filename="../JournalsPlug.cpp" line="47"/>
        <source>Notes</source>
        <translation>Notities</translation>
    </message>
    <message>
        <location filename="../JournalsPlug.cpp" line="125"/>
        <source>Edit</source>
        <translation>Bewerken</translation>
    </message>
    <message>
        <location filename="../JournalsPlug.cpp" line="126"/>
        <source>Clone</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../JournalsPlug.cpp" line="127"/>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../MainWindow.cpp" line="63"/>
        <source>Month</source>
        <translation>Maand</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="64"/>
        <source>Week</source>
        <translation>Week</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="65"/>
        <source>Agenda</source>
        <translation>Agenda</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="66"/>
        <source>Tasks</source>
        <translation>Taken</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="67"/>
        <source>Notes</source>
        <translation>Notities</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="68"/>
        <source>Settings</source>
        <translation>Instellingen</translation>
    </message>
</context>
<context>
    <name>MonthPlug</name>
    <message>
        <location filename="../month/MonthPlug.cpp" line="60"/>
        <source>Previous month</source>
        <translation>Vorige maand</translation>
    </message>
    <message>
        <location filename="../month/MonthPlug.cpp" line="61"/>
        <source>Next month</source>
        <translation>Volgende maand</translation>
    </message>
    <message>
        <location filename="../month/MonthPlug.cpp" line="62"/>
        <source>Jump to today</source>
        <translation>Ga naar vandaag</translation>
    </message>
    <message>
        <location filename="../month/MonthPlug.cpp" line="63"/>
        <source>Jump to</source>
        <translation>Ga naar</translation>
    </message>
    <message>
        <location filename="../month/MonthPlug.cpp" line="64"/>
        <source>New event</source>
        <translation>Nieuwe gebeurtenis</translation>
    </message>
</context>
<context>
    <name>NewComponentWidget</name>
    <message>
        <location filename="../NewComponentWidget.h" line="24"/>
        <source>New event</source>
        <translation>Nieuwe gebeurtenis</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../ChangeManager.cpp" line="180"/>
        <source>Unable to edit birthdays</source>
        <translation>Niet mogelijk geboortedatum te wijzigen</translation>
    </message>
    <message>
        <location filename="../ChangeManager.cpp" line="195"/>
        <source>Delete component?</source>
        <translation>Onderdeel verwijderen?</translation>
    </message>
    <message>
        <location filename="../CWrapper.h" line="59"/>
        <source>Private</source>
        <translation>Privé</translation>
    </message>
    <message>
        <location filename="../CWrapper.h" line="61"/>
        <source>Birthdays</source>
        <translation>Verjaardagen</translation>
    </message>
</context>
<context>
    <name>RecurrencePickDialog</name>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="6"/>
        <source>Recurrence</source>
        <translation>Herhaling</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="27"/>
        <source>Repeat</source>
        <translation>Herhaal</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="37"/>
        <source>View</source>
        <translation>Bekijk</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="58"/>
        <source>Frequency</source>
        <translation>Frequentie</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="69"/>
        <source>Daily</source>
        <translation>Dagelijks</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="74"/>
        <source>Weekly</source>
        <translation>Wekelijks</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="79"/>
        <source>Monthly</source>
        <translation>Maandelijks</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="84"/>
        <source>Yearly</source>
        <translation>Jaarlijks</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="92"/>
        <source>Interval</source>
        <translation>Interval</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="116"/>
        <source>Forever</source>
        <translation>Voor altijd</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="121"/>
        <source>Until</source>
        <translation>Tot</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="126"/>
        <source>Count</source>
        <translation>Keren</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="191"/>
        <source>Week start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.cpp" line="36"/>
        <source>Done</source>
        <translation>Gereed</translation>
    </message>
</context>
<context>
    <name>RecurrencePickSelector</name>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="37"/>
        <source>Never</source>
        <translation>Nooit</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="39"/>
        <source>External</source>
        <translation>Extern</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="41"/>
        <source>Every day</source>
        <translation>Elke dag</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="43"/>
        <source>Every workday</source>
        <translation>Elke werkdag</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="45"/>
        <source>Every week</source>
        <translation>Elke week</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="47"/>
        <source>Every month</source>
        <translation>Elke maand</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="49"/>
        <source>Every year</source>
        <translation>Elke jaar</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="51"/>
        <source>Complex</source>
        <translation>Complex</translation>
    </message>
</context>
<context>
    <name>RulePickDialog</name>
    <message>
        <location filename="../recurrence/RulePickDialog.ui" line="6"/>
        <source>Select rule</source>
        <translation>Selecteer regel</translation>
    </message>
    <message>
        <location filename="../recurrence/RulePickDialog.cpp" line="16"/>
        <source>New</source>
        <translation>Nieuw</translation>
    </message>
    <message>
        <location filename="../recurrence/RulePickDialog.cpp" line="17"/>
        <source>Delete</source>
        <translation>Verwijder</translation>
    </message>
    <message>
        <location filename="../recurrence/RulePickDialog.cpp" line="18"/>
        <source>Done</source>
        <translation>Gereed</translation>
    </message>
</context>
<context>
    <name>RulePickSelector</name>
    <message>
        <location filename="../recurrence/RulePickSelector.cpp" line="14"/>
        <source>Rule %1 of %2</source>
        <translation>Regel %1 van %2</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settings/SettingsDialog.ui" line="6"/>
        <source>Settings</source>
        <translation>Instellingen</translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.ui" line="20"/>
        <source>Edit calendars</source>
        <translation>Kalender bewerken</translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.ui" line="30"/>
        <source>Alarm tone</source>
        <translation>Alarm signaal</translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.ui" line="40"/>
        <source>Delete events</source>
        <translation>Verwijder gebeurtenissen</translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.ui" line="50"/>
        <source>Delete tasks</source>
        <translation>Verwijderen taken</translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.ui" line="60"/>
        <source>First day of week</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.ui" line="70"/>
        <source>Date formats</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.cpp" line="19"/>
        <source>Save</source>
        <translation>Opslaan</translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.cpp" line="65"/>
        <source>Never</source>
        <translation>Nooit</translation>
    </message>
    <message numerus="yes">
        <location filename="../settings/SettingsDialog.cpp" line="67"/>
        <location filename="../settings/SettingsDialog.cpp" line="69"/>
        <source>Older than %n week(s)</source>
        <translation>
            <numerusform>Ouder dan %n week</numerusform>
            <numerusform>Ouder dan %n weken</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../settings/SettingsDialog.cpp" line="71"/>
        <source>Older than %n month(s)</source>
        <translation>
            <numerusform>Ouder dan %n maand</numerusform>
            <numerusform>Ouder dan %n maanden</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../settings/SettingsDialog.cpp" line="73"/>
        <source>Older than %n year(s)</source>
        <translation>
            <numerusform>Ouder dan %n jaar</numerusform>
            <numerusform>Ouder dan %n jaar</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>TodoEditDialog</name>
    <message>
        <location filename="../TodoEditDialog.ui" line="28"/>
        <source>Done</source>
        <translation>Gereed</translation>
    </message>
    <message>
        <location filename="../TodoEditDialog.ui" line="35"/>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <location filename="../TodoEditDialog.ui" line="42"/>
        <source>Calendar</source>
        <translation>Kalender</translation>
    </message>
    <message>
        <location filename="../TodoEditDialog.ui" line="49"/>
        <source>Alarm</source>
        <translation>Alarm</translation>
    </message>
    <message>
        <location filename="../TodoEditDialog.ui" line="56"/>
        <source>Description</source>
        <translation>Beschrijving</translation>
    </message>
    <message>
        <location filename="../TodoEditDialog.cpp" line="28"/>
        <source>Edit task</source>
        <translation>Taak bewerken</translation>
    </message>
    <message>
        <location filename="../TodoEditDialog.cpp" line="31"/>
        <source>New task</source>
        <translation>Nieuwe taak</translation>
    </message>
</context>
<context>
    <name>TodoWindow</name>
    <message>
        <location filename="../TodoWindow.ui" line="6"/>
        <source>Task</source>
        <translation>Taak</translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="41"/>
        <source>Done</source>
        <translation>Gereed</translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="50"/>
        <source>Due</source>
        <translation>Vervalt</translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="80"/>
        <source>Alarm</source>
        <translation>Alarm</translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="169"/>
        <source>Edit task</source>
        <translation>Taak bewerken</translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="174"/>
        <source>Delete task</source>
        <translation>Taak verwijderen</translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="179"/>
        <source>Clone task</source>
        <translation>Taak kopiëren</translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="184"/>
        <source>Automatic links</source>
        <translation>Automatische verwijzingen</translation>
    </message>
    <message>
        <location filename="../TodoWindow.cpp" line="172"/>
        <source>Edit</source>
        <translation>Bewerken</translation>
    </message>
    <message>
        <location filename="../TodoWindow.cpp" line="173"/>
        <source>Clone</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../TodoWindow.cpp" line="174"/>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TodosPlug</name>
    <message>
        <location filename="../TodosPlug.cpp" line="34"/>
        <source>New task</source>
        <translation>Nieuwe taak</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="41"/>
        <source>Hide completed</source>
        <translation>Verberg afgerond</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="42"/>
        <source>Delete completed</source>
        <translation>Verwijder afgerond</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="79"/>
        <source>Tasks</source>
        <translation>Taken</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="203"/>
        <source>Edit</source>
        <translation>Bewerken</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="204"/>
        <source>Clone</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="205"/>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="235"/>
        <source>Delete completed tasks from all calendars?</source>
        <translation>Afgeronde taken van alle kalenders verwijderen?</translation>
    </message>
</context>
<context>
    <name>TunePickDialog</name>
    <message>
        <location filename="../settings/TunePickDialog.ui" line="6"/>
        <source>Choose alarm tone</source>
        <translation>Kies alarm signaal</translation>
    </message>
    <message>
        <location filename="../settings/TunePickDialog.cpp" line="17"/>
        <source>More</source>
        <translation>Meer</translation>
    </message>
    <message>
        <location filename="../settings/TunePickDialog.cpp" line="18"/>
        <source>Done</source>
        <translation>Gereed</translation>
    </message>
    <message>
        <location filename="../settings/TunePickDialog.cpp" line="67"/>
        <source>Add alarm tone</source>
        <translation>Voeg alarm signaal toe</translation>
    </message>
</context>
<context>
    <name>WeekButton</name>
    <message>
        <location filename="../month/WeekButton.cpp" line="33"/>
        <source>w%1</source>
        <translation>w%1</translation>
    </message>
</context>
<context>
    <name>WeekPlug</name>
    <message>
        <location filename="../week/WeekPlug.cpp" line="43"/>
        <source>Previous week</source>
        <translation>Vorige week</translation>
    </message>
    <message>
        <location filename="../week/WeekPlug.cpp" line="44"/>
        <source>Next week</source>
        <translation>Volgende week</translation>
    </message>
    <message>
        <location filename="../week/WeekPlug.cpp" line="45"/>
        <source>Jump to today</source>
        <translation>Ga naar vandaag</translation>
    </message>
    <message>
        <location filename="../week/WeekPlug.cpp" line="46"/>
        <source>Jump to</source>
        <translation>Ga naar</translation>
    </message>
    <message>
        <location filename="../week/WeekPlug.cpp" line="47"/>
        <source>New event</source>
        <translation>Nieuwe gebeurtenis</translation>
    </message>
    <message>
        <location filename="../week/WeekPlug.cpp" line="70"/>
        <source>Week %1 (%2)</source>
        <translation>Week %1 (%2)</translation>
    </message>
</context>
<context>
    <name>WeekWidget</name>
    <message>
        <location filename="../week/WeekWidget.cpp" line="364"/>
        <source>All day</source>
        <translation>Hele dag</translation>
    </message>
</context>
</TS>
